
#$Id: ezmlmrc.sv,v 1.13 1998/11/10 03:53:51 lindberg Exp $
#Name:$
#
# ezmlmrc 
# #######
# Controls the actions of ezmlm-make as patched with ezmlm-idx-0.20 or later.
#
# The base directory 'DIR' is always created by ezmlm-make, as is DIR/key.
# Everything else is done from here.
#
# ezmlm-make looks for this file, first as .ezmlmrc in the directory that the
# lists .qmail files will be placed in (if you've used the -c command line
# switch), then /etc/ezmlmrc, then ezmlmrc in the ezmlm-make binary directory.
# Thus, you can customize ezmlm-make on a global level by placing a customized
# copy of ezmlmrc in /etc and on a user level by copying it to .ezmlmrc in
# the user's home directory AND use the ezmlm-make -c switch.
#
# Tags are:
#	</filename/>       : put succeeding text lines in DIR/filename
#	</-filename/>      : erase DIR/filename.
#	</+dirname/>       : create directory DIR/dirname
#	</:lname/dirname>  : symlink DIR/.qmail-list-lname -> DIR/dirname
#
# The name in the tag can be suffixed with '#' and any number of flags,
# corresponding to command line switches. The item will be created/extended
# only if all the flags listed are set. Files can be extended as long as they
# were the last one created, but not if another file has been started since
# then. Flags that are not recognized are silently ignored.
# 
# Thus, </filename#aP/> creates the file if and only if the list is archived
# (-a) and not public (-P). If the next tag is </filename#m/>, the file is
# extended with the lines up to the next tag if the list is message moderated
# (-m). If the next tag is </another/>, 'filename' is closed. Any further
# tags leading to the reopenining of 'filename' will overwrite the file, not
# extend it.
#
# A set of user-defined command line switches (xX, yY, zZ) are available for
# customization.
#
# Within the text, certain tags are substituted. Other tags are copied as
# is. <#A#> and <#R#> are substituted by ezmlm-manage and -store (see man pages)
# and <#l#> (lower case L) is replaced dynamically by the list name for
# programs handling both 'list' and 'list-digest'.
#
# Substitutions are:
# <#B#> ezmlm binaries path   <#C#> digest code         <#D#> dir
# <#H#> host                  <#L#> local               <#F#> flags
# <#T#> dot                   <#0#> arg for -0. <#3#>...<#9#> arg for -3..9
# <#1#> ext1                  <#2#> ext2 [if dot is /path/.qmail-ext1-ext2-name]
# The latter useful when a single user is controlling several virtual domains.
#
# -0 is used for the main list address when setting up sublists
# -4 for specifying the ezmlm-tstdig switches used in dir/editor. Default
#    -k64 -m30 -t24. Only used if -g is used.
# -5 for list-owner address. Mail to list-owner will be forwarded to this addr.
# -7 for contents of DIR/modpost
# -8 for contents of DIR/modsub
# -9 for contents of DIR/remote
#
# For demonstration purposes, the '-x' switch results in the following
# non-standard actions:
# - Removal of many non-text MIME parts from messages.
# - Limit posts to 2 bytes <= msg body size <= 40000
#
# Attempts to create links or directories that already exist, will result
# in a FATAL error. Attempts to open files that have already been closed
# or already exits, will cause the old file to be overwritten.
#
# One of the major problems with ezmlm-lists is DIR/inlocal. For normal
# users, it is set up to the list name (user-list or so), which is correct.
# However, for user 'ezmlm' in control of virtual domain 'host.dom.com'
# the list name is 'list@host.dom.com', but inlocal should be 'ezmlm-list',
# not 'list'. Similarly, if ezmlm-domain1 is in control of 'host.dom.com,
# list@host.dom.com, should yield an inlocal of 'ezmlm-domain1-list'. To
# always get the lists correct, place this file as '.ezmlmrc' in the 
# users home directory (~ezmlm/.ezmlmrc) and change the inlocal text below
# to 'ezmlm-<#L#>' or 'ezmlm-<#1#>-<#L#>, respectively.
# config to support future editing withour giving ezmlm-make command line
# arguments other than dir. Useful for GUI/WWW editing tools
</config/>
F:<#F#>
D:<#D#>
T:<#T#>
L:<#L#>
H:<#H#>
C:<#C#>
0:<#0#>
3:<#3#>
4:<#4#>
5:<#5#>
6:<#6#>
7:<#7#>
8:<#8#>
9:<#9#>
</charset/>
# Explicitly specify character-set, when this ezmlmrc was used.
# Use Quoted-Printable to make averyone happy.
iso-8859-1:Q
</inlocal/>
<#L#>
</sublist#0/>
<#0#>
</+archive/>
</+subscribers/>
</+bounce/>
</+text/>
# dirs for digests
</+digest#d/>
</+digest/subscribers#d/>
</+digest/bounce#d/>
# for extra address db
</+extra/>
</+extra/subscribers/>
# for blacklist
</+blacklist#k/>
</+blacklist/subscribers#k/>
# moderator db & mod queue dirs. Needed for -m, -r -s, so we just
# make them by default.
</+mod/>
</+mod/subscribers/>
</+mod/pending/>
</+mod/accepted/>
</+mod/rejected/>
# links: dot -> dir/editor
</:/editor/>
</:-owner/owner/>
</:-digest-owner/owner#d/>
</:-return-default/bouncer/>
</:-digest-return-default/bouncer#d/>
</:-default/manager/>
# for message moderation only
</:-accept-default/moderator#m/>
</:-reject-default/moderator#m/>
# Get rid of configuration flags for editing mode so we can start with a
# clean slate.
</-modpost#eM/>
</-modsub#eS/>
</-remote#eR/>
</-public#eP/>
</-indexed#eI/>
</-archived#eA/>
</-prefix#eF/>
</-text/trailer#eT/>
</-sublist#e^0/>
</-mimeremove#eX/>
# Not needed, except for message moderation.
</-moderator#eM/>
# We don't clean out text files to make it easier for users
# doing manual config by e.g. touching dir/remote.
# subscription moderation
</modsub#s/>
<#8#>
# remote admin
</remote#r/>
<#9#>
# message moderation
</modpost#m/>
<#7#>
# List owner mail
</owner#5/>
<#5#>
</owner#^5/>
<#D#>/Mailbox
<//>
|<#B#>/ezmlm-warn '<#D#>' || exit 0
# Handles subscription. Add flags if you want a non-default digest format.
# Service subject commands to the # request address if the -q switch is given.
# Also -l and -d enable subscriber listing/text file editing, for remote adms.
# -u gives subscriber only archive access
</manager#iG/>
|<#B#>/ezmlm-get '<#D#>' <#C#>
</manager#ig/>
|<#B#>/ezmlm-get -s '<#D#>' <#C#>
</manager#q/>
|<#B#>/ezmlm-request '<#D#>'
# Ok to add -l/-d even for non-mod lists, since ezmlm-manage
# won't allow it unless there are remote admins.
</manager#LN/>
|<#B#>/ezmlm-manage '<#D#>'
</manager#lN/>
|<#B#>/ezmlm-manage -l '<#D#>'
</manager#Ln/>
|<#B#>/ezmlm-manage -e '<#D#>'
</manager#ln/>
|<#B#>/ezmlm-manage -le '<#D#>'
</manager/>
|<#B#>/ezmlm-warn '<#D#>' || exit 0
</#d/>
|<#B#>/ezmlm-warn -d '<#D#>' || exit 0
</editor/>
# reject shouldn't be configured for sublist.
</#^0/>
# full reject is now default, to get To/Cc: listaddress requirement
|<#B#>/ezmlm-reject '<#D#>'
# -k => silently ignore posts from blacklisted addresses. Done for moderated
# lists as well - allows removal of unwanted noise.
</#k^0/>
|<#B#>/ezmlm-issubn -n '<#D#>/blacklist' || { echo "Jag har blivit tillsagd att inte tillta dina postningar. Kontakta <#L#>-owner@<#H#> ifall du har ngra frgor angende detta (#5.7.2)"; exit 100 ; }
# switch -u=> restrict to subs of list & digest. If not m
# do it with ezmlm-issubn, if 'm' do it with ezmlm-gate
</#uM/>
|<#B#>/ezmlm-issubn '<#D#>' '<#D#>/digest' '<#D#>/extra' || { echo "Tyvrr, endast prenumeranter fr posta. Ifall du r en prenumerant, vidareskicka detta medelande till <#L#>-owner@<#H#> fr att f din nya address inlaggd (#5.7.2)"; exit 100 ; }
</#um/>
|<#B#>/ezmlm-gate '<#D#>' '<#D#>' '<#D#>/digest' '<#D#>/extra' '<#D#>/mod'
# For message moderation, editor has store/clean
</#mU/>
|<#B#>/ezmlm-store '<#D#>'
|<#B#>/ezmlm-clean '<#D#>' || exit 0
</#mu/>
|<#B#>/ezmlm-clean -R '<#D#>' || exit 0
# for non-message moderated lists, it has send
</#M/>
|<#B#>/ezmlm-send '<#D#>'
# all lists have warn.
<//>
|<#B#>/ezmlm-warn '<#D#>' || exit 0
# for digest bounces
</#d/>
|<#B#>/ezmlm-warn -d '<#D#>' || exit 0
</#d^4/>
|<#B#>/ezmlm-tstdig -m30 -k64 -t48 '<#D#>' || exit 99
</#d4/>
|<#B#>/ezmlm-tstdig <#4#> '<#D#>' || exit 99
</#d/>
|<#B#>/ezmlm-get '<#D#>' || exit 0
</bouncer/>
|<#B#>/ezmlm-weed
|<#B#>/ezmlm-return '<#D#>'
# moderator is set up only for message moderated lists. However, '-e' does
# not remove it since we can't remove the symlinks to it (they're outside
# of the list dir.
</moderator#m/>
|<#B#>/ezmlm-moderate '<#D#>'
</#mU/>
|<#B#>/ezmlm-clean '<#D#>' || exit 0
</#mu/>
|<#B#>/ezmlm-clean -R '<#D#>' || exit 0
</headerremove#E/>
return-path
return-receipt-to
content-length
</lock/>
</lockbounce/>
</digest/lockbounce#d/>
</digest/lock#d/>
</public#p/>
</archived#a/>
</indexed#i/>
</inhost/>
<#H#>
</outhost/>
<#H#>
</outlocal/>
<#L#>
</mailinglist/>
contact <#L#>-help@<#H#>; run by ezmlm
# Headeradd needs to always exist
</headeradd#E/>
# Good for mailing list stuff (and vacation program)
Precedence: bulk
# max & min message size
</msgsize#x/>
40000:2
# remove mime parts if -x
</mimeremove#x/>
application/excel
application/rtf
application/msword
application/ms-tnef
text/html
text/rtf
text/enriched
text/x-vcard
application/activemessage
application/andrew-inset
application/applefile
application/atomicmail
application/dca-rft
application/dec-dx
application/mac-binhex40
application/mac-compactpro
application/macwriteii
application/news-message-id
application/news-transmission
application/octet-stream
application/oda
application/pdf
application/postscript
application/powerpoint
application/remote-printing
application/slate
application/wita
application/wordperfect5.1
application/x-bcpio
application/x-cdlink
application/x-compress
application/x-cpio
application/x-csh
application/x-director
application/x-dvi
application/x-hdf
application/x-httpd-cgi
application/x-koan
application/x-latex
application/x-mif
application/x-netcdf
application/x-stuffit
application/x-sv4cpio
application/x-sv4crc
application/x-tar
application/x-tcl
application/x-tex
application/x-texinfo
application/x-troff
application/x-troff-man
application/x-troff-me
application/x-troff-ms
application/x-ustar
application/x-wais-source
audio/basic
audio/mpeg
audio/x-aiff
audio/x-pn-realaudio
audio/x-pn-realaudio
audio/x-pn-realaudio-plugin
audio/x-realaudio
audio/x-wav
image/gif
image/ief
image/jpeg
image/png
image/tiff
image/x-cmu-raster
image/x-portable-anymap
image/x-portable-bitmap
image/x-portable-graymap
image/x-portable-pixmap
image/x-rgb
image/x-xbitmap
image/x-xpixmap
image/x-xwindowdump
text/x-sgml
video/mpeg
video/quicktime
video/x-msvideo
video/x-sgi-movie
x-conference/x-cooltalk
x-world/x-vrml
# These can also be excluded, but for many lists it is desirable
# to allow them. Uncomment to add to mimeremove.
# application/zip
# application/x-gtar
# application/x-gzip
# application/x-sh
# application/x-shar
# chemical/x-pdb
</prefix#f/>
[<#L#>]
</text/trailer#t/>
---------------------------------------------------------------------
Fr att avsluta prenumerationen, skicka e-mail till:
    <#L#>-unsubscribe@<#H#>
Fr en lista p kommandon, skicka e-mail till:
    <#L#>-help@<#H#>
</text/bottom/>

--- Detta r ezmlms kommandoaddresser:

Jag kan hantera administrativa frfrgningar automatiskt. Skicka inga
sdana frfrgningar till listan, det kommer inte att fungera och andra
prenumeranter kan bli frargade.

Fr att prenumerera p listan, skicka ett medelande till:
   <<#L#>-subscribe@<#H#>>

Fr att avsluta er prenumeration p listan, skicka ett brev till:
   <<#L#>-unsubscribe@<#H#>>

Send mail to the following for info and FAQ for this list:
   <<#L#>-info@<#H#>>
   <<#L#>-faq@<#H#>>

</#d/>
Samma addresser finns fr att prenumerera p en "digest" version av listan:
   <<#L#>-digest-subscribe@<#H#>>
   <<#L#>-digest-unsubscribe@<#H#>>

# ezmlm-make -i needed to add ezmlm-get line. If not, we can't do
# multi-get!
</text/bottom#ai/>
Fr att f medelande 12 till och med 45 (max 100 per frfrgan), skicka:
   <<#L#>-get.12_45@<#H#>>

</text/bottom#aI/>
Fr att f medelande 12 frn listans arkiv, skicka till:
   <<#L#>-get.12@<#H#>>

</text/bottom#i/>
Fr att f titlarna p medelande 123-456, skicka till:
   <<#L#>-index.123_456@<#H#>>

Resultatet kommer i brev med hundra titlar per brev, max 2000
per frga, s i detta fallet skulle ni ftt 100-499.

# Lists need to be both archived and indexed for -thread to work
</text/bottom#ai/>
 
Fr att f en kopia av alla medelanden som har samma titel
som det 12345:e medelandet, skicka ett brev till:
   <<#L#>-thread.12345@<#H#>>

# The '#' in the tag below is optional, since no flags follow.
# The name is optional as well, since the file will always be open
# at this point.
</text/bottom#/>
SKICKA INTE ADMINISTRATIVA FRFRGNINGAR TILL LISTAN!
Ifall du gr det kommer inte jag att se dem och de andra prenumeranterna
kommer bli arga p dig.

Fr att specifisera God@heaven.af.mil som din prenumerationsaddress,
skicka ett medelande till <<#L#>-subscribe-God=heaven.af.mil@<#H#>>.
Jag kommer skicka ett bekrftelsebrev till den addressen och nr
du fr det medelandet behver du bara svara p det fr att pbrja
din prenumeration.

Ifall du inte frstr dessa instruktioner eller om allt inte
fungerar som det skall, var vnlig kontakta min gare p address
<#L#>-owner@<#H#>. Var beredd p att min gare r mycket
lngsammare n jag r! ;-)

--- Bifogat r en kopia av den frfrgan jag fick.

</text/bounce-bottom/>

--- Nedanfr denna raden fljer en kopia av medelandet som studsade.

</text/bounce-num/>

Jag har skapat en lista p brev frn <#L#> listan som har kommit
tillbaka nr jag frskt skicka dem till dig. Kopior av dessa
medelanden kan du hitta i listans arkiv. Fr att f medelande
12345 frn arkivet skicka ett tomt medelande till
<#L#>-get.12345@<#H#>.

</#ia/>
Fr att f en lista med titlar och frfattare ver de hundra senaste
medelandena skicka ett tomt brev till <#L#>-index@<#H#>.

Fr att f innehllet i medelande 123-145 (maximalt 100 per frfrgan)
skicka ett tomt brev till <#L#>-get.123_145@<#H#>.

<//>
Detta r medelande nummren:

</text/dig-bounce-num/>
Jag har skapat en lista p brev frn <#L#>-digest listan som har
kommit tillbaka nr jag frskt skicka dem till dig. Kopior av dessa
medelanden kan du hitta i listans akriv. Fr varje digest som du
missat har jag sparat numret p frsta medelandet i digest:en. Fr
att f medelande 12345 frn arkivet skicka ett tomt medelande till
<#L#>-get.12345@<#H#>.

</#ia/>
Fr att f en lista med titlar och frfattare ver de hundra senaste
medelandena skicka ett tomt brev till <#L#>-index@<#H#>.

Fr att f innehllet i medelande 123-145 (maximalt 100 per frfrgan)
skicka ett tomt brev till <#L#>-get.123_145@<#H#>.

<//>
Detta r digest medelande nummren:

</text/bounce-probe/>

Medelanden till dig frn <#l#> listan verkar inte ha kommit fram.
Jag skickade ett varningsbrev till dig, men det kom inte heller
fram. Bifogat till detta brev fljer en kopia av felmedelandet som
jag fick.

Detta r en test fr att se om din address kan ns. Ifall detta
brevet inte heller kommer fram kommer er address tas bort frn
<#l#>@<#H#> listan utan vidare korrespondans.

</text/bounce-warn/>

Medelanden till dig frn <#l#> listan varkar inte ha kommit fram.
Jag har bifogat en kopia av det frsta felmedelandet som jag fick.

Ifall detta brev ocks genererar ett felmedelande kommer jag
skicka ett testmedelande. Ifall testmedelandet ocks ger ett
felmedelande kommer jag att ta bort din address frn <#l#>
listan utan ytterligare korrespondans.

</text/digest#ia/>
Fr att prenumerera p en "digest" version av listan, skicka ett
tomt brev till:
        <#L#>-digest-subscribe@<#H#>

Fr att sluta prenumerera p en "digest" version av listan,
skicka ett tomt brev till:
        <#L#>-digest-unsubscribe@<#H#>

Fr att skicka brev till listan, skicka brevet till:
        <#L#>@<#H#>

</text/get-bad/>
Tyvrr finns inte det medelandet i arkivet.

</text/help/>
Detta r ett generellt hjlpmedelande. Medelandet jag fick var inte
skickat till ngon av mina kommandoaddresser.

</text/mod-help/>
Tack fr att du ville moderera <#L#>@<#H#> listan.

Mina kommandon r lite annorlunda gentimot mnga andra listor.
De verkar skert udda till en brjan, men nr du vl brjar anvnda
dem kommer du att uppskatta systemet och min hastighet nr jag
tar hand om dina kommandon.

Hr fljer lite kortfattad information om hur man modererar en lista:

Fjrrprenumeration
------------------
Som moderator kan du prenumerera och avsluta prenumerationen fr
john@johnhost.johndomain genom att skicka brev till:

<#L#>-subscribe-john=johnhost.johndomain@<#H#>
<#L#>-unsubscribe-john=johnhost.johndomain@<#H#>

</#d/>
Fr digest versionen:

<#L#>-digest-subscribe-john=johnhost.johndomain@<#H#>
<#L#>-digest-unsubscribe-john=johnhost.johndomain@<#H#>

<//>
Det r allt som krvs. Ingen speciell titel eller brevtext behvs.

</#r/>
Jag kommer skicka en bekrftelse frfrgan till dig fr s jag vet
det verkligen var du som skickade kommandot. Svara bara p medelandet
och sedan r det klart.
</#R/>
Jag kommer skicka en bekrftelse frfrgan till anvndarens address.
Allt anvndaren behver gra r att svara p bekrftelsen.
<//>

Jag kommer medela anvndaren angende frndringen.

Prenumeration
-------------

Alla kan prenumerera eller avsluta sin prenumeration genom att skicka
ett tomt brev till:

<#L#>-subscribe@<#H#>
<#L#>-unsubscribe@<#H#>

</#d/>
Fr digest versionen:

<#L#>-digest-subscribe@<#H#>
<#L#>-digest-unsubscribe@<#H#>

Anvndaren kommer att f en bekrftelsefrfrgan som hon mste
svara p fr att pbrja/avsluta prenumerationen.

</#s/>
Fr prenumerationer kommer en andra bekrftelsefrfrgan att skickas
till moderatorn/moderatorerna.
Ett svar frn en moderator rcker fr att slutfra transaktionen.
</#S/>
Prenumerationer fungerar p samma stt.
<//>

Anvndaren kan ocks anvnda:

<#L#>-subscribe-john=johnhost.johndomain@<#H#>
<#L#>-unsubscribe-john=johnhost.johndomain@<#H#>

fr att skicka brevet till en annan address som personen har.
Bara om personen har john@johnhost.johndomain som address kommer
personen att f bekrftelsefrfrgan.

Allt detta ser till att ingen kan prenumerare ngon annan
mot dennes vilja och att du som moderator kan vara sker
p att prenumeranterna r frivilligt med p listan.

Din address och identitet kommer jag aldrig avslja fr prenumeranterna.

</#rl/>
Fr att f en prenumerantlista fr <#L#>@<#H#>,
skicka ett brev till:
   <<#L#>-list@<#H#>>

Fr att f en transaktionslog fr <#L#>@<#H#>,
skicka ett brev till:
   <<#L#>-log@<#H#>>

</#rld/>
For digest versionen:
   <<#L#>-digest-list@<#H#>>
och:
   <<#L#>-digest-log@<#H#>>

</#rn/>
Du kan ocks ndra texterna som utgr listans svar p administrativa
frfrgningar. Fr mera information, skicka ett brev till:
   <<#L#>-edit@<#H#>>

</#m/>
Modererade utskick
------------------
Nr utskick r modererade kommer jag att lgga postade
medelanden i en k och frga moderatorerna om det r ok
att skicka ut dem.

Som moderator behver du bara skicka ett brev till 'Reply-To:'
addressen (sker i de allra flesta program automatiskt ifall du vljer
att svara p brevet) ifall du accepterar utskicket.

Ifall du inte accepterar utskicket skickar du bara ett medelande
till 'From:' addressen istllet.
Du kan skriva en kommentar till frfattaren mellan de tv raderna som
brjar med %%%.

Det frsta svaret jag fr frn en moderator avgr medelandets de.
Ifall ditt svar inte r detsamma som det frsta svaret jag fick
kommer jag att medela dig om det.

Ifall jag inte fr ngot svar frn ngon moderator inom en given tid
(vanligtvis fem dagar) kommer jag att returnera brevet till avsndaren
med en frklaring om vad som hnt.

<//>

Semestrar
---------
Ifall du temporrt har en annan e-mail address, vidareskicka alla
brev som har rtt 'Mailing-List:' header eller alla brev som har
som titel 'MODERATE for <#L#>@<#H#>' eller
'CONFIRM subscribe to <#L#>@<#H#>' till den nya addressen eller till
ngon som tar hand om modererandet medan du r borta. Se till att
listans gare tycker att detta r OK.

Ifall du vill att allt skall automatiskt godknnas medan du r borta,
stt upp er mailklient s den gr ett "auto-reply" p de medelanden
som har rtt titel.

</#r/>
Ifall du frsker fjrradministrera listan frn en address som inte
r din prenumerationsaddress kommer prenumeranten att frgas frst
och drefter frgas moderatorerna fr bekrftelse.
Jag gr bara s fr jag kan inte veta att det verkligen r du som
skickade det ursprungliga kommandot.

Observera att ditt kommando (och din address) kommer att skickas
till prenumeranten i s fall!
<//>

Lycka till!

PS: Kontakta listgaren (<#L#>-owner@<#H#>) ifall du har ngra
frgor eller sttt p ngot problem.

</text/mod-reject/>
Tyvrr, ditt medelande accepterades inte av moderatorn.
Ifall moderatorn hade ngra kommentarer s visas de nedan.
</text/mod-request/>
Det medfljande medealndet var skickat till <#L#>@<#H#> listan.
Ifall du godknner att detta distribueras till alla prenumeranter,
skicka ett medelande till:

!A

Vanligtvis rcker det med att du anvnder "reply"/"svara" funktionen i
ditt e-mail program. Du kan kontrollera att addressen startar med
"<#L#>-accept". Ifall det inte fungerar, kopiera addressen och
klistra in den i "To:"/"Till:" fltet i ett nytt brev.
</#x/>

Alternativt, klicka hr:
        mailto:<#A#>
<//>

Fr att avvisa utskicket och snda medelandet tillbaka till avsndaren,
skicka ett medelande till:

!R

Vanligtvis r det lttaste sttet att vlja "Svara alla"/"reply-to-all"
och sedan ta bort alla addresser utom den som brjar med
"<#L#>-reject".
</#x/>

Alternativt, klicka hr:
        mailto:<#R#>
<//>

Du behver inte kopiera medelandet i ditt svar fr att acceptera
eller avvisa det. Ifall du vill skicka en kommentar till
frfattaren, skriv den mellan tv rader som brjar med tre procent
tecken ('%'):

%%% Kommentarsstart
%%% Kommentarsslut

Tack fr din hjlp!

--- Bifogat finner du det postade medelandet.

</text/mod-sub#E/>
--- Jag har (av)prenumererat dig p uppdrag av en moderator fr
<#l#>@<#H#> listan.

Ifall detta inte r ngot som du samtycker med, skicka ett klagoml
eller annan kommentar till listgaren (<#l#>-owner@<#H#>) s snabbt
som mjligt.

Ifall du vill ha information om vilka kommandon jag frstr,
skicka ett tomt brev till <#L#>-help@<#H#>.

</text/mod-timeout/>
Tyvrr har listans moderatorer inte agerat angende ditt utskick
till listan och drfr returnerar jag nu ditt medelande. Ifall du
tror att det har intrffat ngot fel, skicka medelandet igen till
listan eller kontakta en av listans moderatorer.

--- Bifogat r ert medelande till listan.

</text/mod-sub-confirm/>
Jag skulle vilja ha din tilltelse att addera

!A

till <#l#> listans prenumeranter. Ifall denna frfrgan
inte ursprungligen kom frn dig har jag redan ftt en
bekrftelse frn prenumeranten.

Fr att bekrfta, skicka ett tomt medelande till denna address:

!R

Ditt e-mail program borde ha en svarsfunktion som anvnder denna
address automatiskt. Ifall det inte fungerar, kopiera addressen
och klistra in den i "To:"/"Till:" fltet i ett nytt medelande.
</#x/>

eller klicka hr:
        mailto:<#R#>
<//>

Ifall du inte samtycker, ignorera detta medelande.

Tack fr din hjlp!

</text/mod-unsub-confirm/>
Jag skulle vilja ha din tilltelse att ta bort

!A

frn <#l#> listan. Ifall du samtycker, skicka ett tomt
medelande till denna address:

!R

Ditt e-mail program borde ha en svarsfunktion som anvnder denna
address automatiskt. Ifall det inte fungerar, kopiera addressen
och klistra in den i "To:"/"Till:" fltet i ett nytt medelande.
</#x/>

eller klicka hr:
        mailto:<#R#>
<//>

Ifall du inte samtycker, ignorera detta medelande.

Tack fr din hjlp!

</text/sub-bad/>
Oj! Bekrftelsenummret verkar vara felaktigt.

Den vanligaste orsaken r att dess tid gtt ut. Jag mste ha en
bekrftelse inom tio dagar fr att den skall glla. En annan orsak
kan vara att du inte skicka med hela nummret. Vissa e-mail program
klipper felaktigt av lnga addresser och i s fall mste du kontakta
list garen (<#L#>-owner@<#H#>) eller skaffa ett bttre program fr
e-mail hantering.

Jag har skapat ett nytt bekrftelsenummer. Fr att bekrfta
att du vill att

!A

skall prenumerera p <#l#> listan, skicka ett tomt medelande
till denna address:

!R

Var noga med att svarsaddressen r korrekt nr du bekrftar prenumerationen.

Urskta detta besvr.

	<#L#>-Owner <<#l#>-owner@<#H#>>

</text/sub-confirm/>
Fr att bekrfta att du vill ha

!A

adderad till <#l#> listan, skicka ett tomt medelande
till denna address:

!R
</#x/>

eller klicka hr:
        mailto:<#R#>
<//>

Ditt email program br ha en funktion som anvnder denna address
automatiskt ifall du svarar p detta brev.

Denna bekrftelse fyller tv funktioner. Dels verifierar den att jag
kan skicka brev till dig och dels skyddar den dig frn att andra
skall addera dig p flera listor mot din vilja.

</text/sub-confirm#s/>
Denna lista r modererad. S fort jag snt denna bekrftelse till
dig kommer listans moderatorer att bli underttade. Jag kommer
att underrtta dig nr din prenumeration blir aktiv.

</text/sub-nop/>
Uppmrksamma: Addressen

!A

r redan medlem av <#l#> listan.

</text/sub-ok#E/>
Uppmrksamma: Jag har adderat 

!A

till <#l#> listan.

Vlkommen till <#l#>@<#H#>!

Spara detta medelande s du vet vilken address du prenumererade under.
Du behver den addressen ifall du senare vill avsluta din prenumeration.

</text/top/>
Hej! Detta r ezmlm programmet. Jag hanterar
<#l#>@<#H#> listan.

Jag arbetar fr min gare som kan ns via <#l#>-owner@<#H#>.

</text/unsub-bad/>
Oj! Bekrftelsenummret verkar vara felaktigt.

Den vanligaste orsaken r att dess tid gtt ut. Jag mste ha en
bekrftelse inom tio dagar fr att den skall glla. En annan orsak
kan vara att du inte skicka med hela nummret. Vissa e-mail program
klipper felaktigt av lnga addresser och i s fall mste du kontakta
list garen (<#L#>-owner@<#H#>) eller skaffa ett bttre program fr
e-mail hantering.

Jag har skapat ett nytt bekrftelsenummer. Fr att bekrfta
att du vill att

!A

skall plockas bort frn <#l#> listan, skicka ett tomt medelande till
denna address:

!R
</#x/>

eller klicka hr:
        mailto:<#R#>
<//>

Var noga med att svarsaddressen r korrekt nr du bekrftar prenumerationen.

Urskta detta besvr.

	<#l#>-Owner <<#l#>-owner@<#H#>>

</text/unsub-confirm/>
Fr att bekrfta att du vill att

!A

plockas bort frn <#l#> listan, skicka ett tomt brev
till denna address:

!R

Ditt email program br ha en svarsfunktion som anvnder denna
address automatiskt. Ifall det inte fungerar, kopiera addressen
och klipp in den i "To:"/"Till:" fltet p ett nytt medelande.
</#x/>

eller klicka hr:
        mailto:<#R#>
<//>

Jag har inte underskt om addressen redan r p listan.
Fr att se vilken address du anvnde nr du prenumererade, titta p
ett medelande som du ftt frn listan. Varje medelande har din e-mail
address gmd i sin "return path", t ex fr God@heaven.af.mil brev frn
listan med "return path:" satt till
<<#L#>-return-<number>-God=heaven.af.mil@<#H#>>.

</text/unsub-nop/>
Uppmrksamma: Addressen

!A

prenumererar inte p <#l#> listan. Den var inte med p listan
nr jag fick ditt kommando.

Ifall du har slutat prenumerera, men fortstter att f brev har du
prenumererat med en annan email address n den du nu anvnder. Titta
i brevets "header" efter:

'Return-Path: <<#l#>-return-1234-user=host.dom@<#H#>>'

Fr att sluta prenumerera, skicka ett brev till;
'<#l#>-unsubscribe-user=host.dom@<#H#>'.
Du kommer d att f en bekrftelse till user@host.dom och nr du svarat
p det medelandet s r du borta frn listan.

Ifall detta inte hjlper dig s kan jag tyvrr inte gra mer.
VIDARESND (FORWARD) i s fall ett medelande frn listan tillsammans
med en kommentar om vad du frsker gra till min gare:

    <#l#>-owner@<#H#>

som kommer att ta hand om det. Min gare r lngsammare n jag s du
fr ha lite tlamod.

Urskta detta extra besvr.
</text/unsub-ok/>
Uppmrksamma: Jag har tagit bort addressen

!A

frn <#l#> listan.

</text/edit-do#n/>
Var vnlig och editera fljande textfil och skicka den till
denna address:

!R

Ditt mailprogram borde ha en svarsfunktiuon som anvnder
denna address automatiskt. Ifall det inte fungerar, kan du
kopiera addressen och klistra in den i "To:"/"Till:" fltet
p ett nytt medelande.
</#x/>

eller klicka hr:
        mailto:<#R#>
<//>

Jag kan ta bort citeringsmarkeringar (t ex "> ") som din
mailprogramvara lgger till texten s lnge som du inte
ndrar start och slutraderna.

Start och slutraderna r rader som brjar med %%%. De fr inte
ndras. Ifall ditt mailprogram lgger in tecken fre dem s skall
de st kvar.


</text/edit-list#n/>
<#L#>-edit.fil kommandot kan anvndas av en fjrradministratr
fr att editera de textfiler som skapar de svaren jag skickar fr
<#L#>@<#H#> listan.

Hr fljer en lista p de filer som kan ndras samt en
kort beskrivning om hur dess innehll anvnds. Fr att
ndra en fil, skicka ett brev till <#L#>-edit.filnamn dr
du byter ut filnamn mot filens namn. Editeringsinstruktioner
skickas till dig ihop med textfilen.

Fil                 Anvndninsomrde.

bottom              slutet p alla svar. Generell kommando information.
digest              'administrationsbiten' av en 'digest'.
faq                 Vanligt frekommande frgor p denna lista.
get_bad             i stllet fr medelanden som inte hittas i arkivet.
help                generell hjlp (mellan top och bottom).
info                list info. Frsta raden skall kunna visas separat.
mod_help            specifik hjlp fr listmoderatorer.
mod_reject          snds till avsndaren av avvisade medelanden.
mod_request         till medelandemoderatorerna tillsammans med medelandet.
mod_sub             till prenumeranter efter att en moderator bekrftat prenumerationen.
mod_sub_confirm     till prenumerationsmoderatorn fr att bekrfta prenumerationer.
mod_timeout         till sndaren av ett medelande som ingen accepterat/avvisat.
mod_unsub_confirm   till en administratr fr att bekrfta avprenumerationer.
sub_bad             till prenumeranten ifall bekrftelsen var felaktig.
sub_confirm         till prenumeranten fr att bekrfta prenumerationer.
sub_nop             till prenumeranten efter en dubbel prenumeration.
sub_ok              till prenumeranten efter en lyckad prenumeration.
</#tn/>
trailer             adderas till alla utskick innan de kommer till listan.
</#n/>
top                 starten p alla svar. Generell kommando information.
unsub_bad           till prenumeranten ifall avprenumerationen misslyckades.
unsub_confirm       till prenumeranten fr att bekrfta avprenumeration.
unsub_nop           till icke-prenumerant efter avprenumeration.
unsub_ok            till tidigare prenumeration efter avslutad prenumeration.

</text/edit-done#n/>
Textfilen uppdaterades korrekt.
</text/info#E/>
Ingen information har antecknats om listan.
</text/faq#E/>
FAQ - vanligt frekommande frgor p <#l#>@<#H#> listan.

Inga har nedtecknats nnu.

